==> zio-aws-ec2_2.13-5.17.126.1-sources.jar: zio/aws/ec2/model/DefaultTargetCapacityType.scala <==
package zio.aws.ec2.model
import scala.jdk.CollectionConverters._
sealed trait DefaultTargetCapacityType {
  def unwrap
      : software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType
}
object DefaultTargetCapacityType {
  def wrap(
      value: software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType
  ): zio.aws.ec2.model.DefaultTargetCapacityType = value match {
    case software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.SPOT =>
      val r = spot
      r
    case software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.ON_DEMAND =>
      val r = `on-demand`
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.ec2.model.DefaultTargetCapacityType {
    override def unwrap
        : software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType =
      software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.UNKNOWN_TO_SDK_VERSION
  }
  case object spot extends zio.aws.ec2.model.DefaultTargetCapacityType {
    override def unwrap
        : software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType =
      software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.SPOT
  }
  case object `on-demand` extends zio.aws.ec2.model.DefaultTargetCapacityType {
    override def unwrap
        : software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType =
      software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.ON_DEMAND
  }
}

==> zio-aws-ec2_2.13-7.21.15.7-sources.jar: zio/aws/ec2/model/DefaultTargetCapacityType.scala <==
package zio.aws.ec2.model
import scala.jdk.CollectionConverters._
sealed trait DefaultTargetCapacityType {
  def unwrap
      : software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType
}
object DefaultTargetCapacityType {
  def wrap(
      value: software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType
  ): zio.aws.ec2.model.DefaultTargetCapacityType = value match {
    case software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.SPOT =>
      val r = spot
      r
    case software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.ON_DEMAND =>
      val r = `on-demand`
      r
    case software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.CAPACITY_BLOCK =>
      val r = `capacity-block`
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.ec2.model.DefaultTargetCapacityType {
    override def unwrap
        : software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType =
      software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.UNKNOWN_TO_SDK_VERSION
  }
  case object spot extends zio.aws.ec2.model.DefaultTargetCapacityType {
    override def unwrap
        : software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType =
      software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.SPOT
  }
  case object `on-demand` extends zio.aws.ec2.model.DefaultTargetCapacityType {
    override def unwrap
        : software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType =
      software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.ON_DEMAND
  }
  case object `capacity-block`
      extends zio.aws.ec2.model.DefaultTargetCapacityType {
    override def unwrap
        : software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType =
      software.amazon.awssdk.services.ec2.model.DefaultTargetCapacityType.CAPACITY_BLOCK
  }
}
